@@ -10,10 +10,9 @@
 
 header("Content-type: text/plain");
 
-$cache_sys = apc_cache_info('', 1);
-$cache_user = apc_cache_info('user', 1);  
-$memory=apc_sma_info();
-unset($mem['block_lists']);
+$cache_sys = apc_cache_info('', true);
+$cache_user = apc_cache_info('user', true);  
+$memory = apc_sma_info(true);
 
 foreach ($cache_sys as $key => $val) {
   printf("%s:%s:%s\n",'cache_sys', $key, $val); 
@@ -22,9 +21,7 @@ foreach ($cache_user as $key => $val) {
   printf("%s:%s:%s\n",'cache_user', $key, $val); 
 }
 foreach ($memory as $key => $val) {
-  if (! is_array($val)) {
-    printf("%s:%s:%s\n",'memory', $key, $val); 
-  } 
+  printf("%s:%s:%s\n",'memory', $key, $val); 
 }
 
 ?>
