@@ -15,7 +15,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = ["Samuel Stauffer"]
 __license__ = "GPL"
-__version__ = "0.9.19"
+__version__ = "0.9.20"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -37,7 +37,7 @@ class MuninAttrFilter:
     
     """
     
-    def __init__(self, list_include = [], list_exclude = [], 
+    def __init__(self, list_include = None, list_exclude = None,
                  attr_regex = None, default = True):
         """Initialize Munin Attribute Filter.
         
@@ -91,13 +91,17 @@ class MuninPlugin:
     """The name of the plugin executable.
     Must be overriden in child classes to indicate plugin name.
     If it ends with an underscore the name will be parsed to separate plugin
-    argument embedded in the name."""
+    wildcard argument embedded in the name."""
 
     isMultigraph = False
     """True for Multi-Graph Plugins, and False for Simple Plugins.
     Must be overriden in child classes to indicate plugin type."""
+    
+    isMultiInstance = False
+    """True for Multi-Graph Plugins with Multi-Instance support, False otherwise.
+    Must be overriden in child classes to indicate plugin type."""
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Constructor for MuninPlugin Class.
         
         @param argv: List of command line arguments.
@@ -111,10 +115,12 @@ class MuninPlugin:
         self._filters = {}
         self._flags = {}
         self._argv = argv
-        self._env = env
+        self._env = env or {}
         self.arg0 = None
         self._debug = debug
         self._dirtyConfig = False
+        self._instanceName = None
+        self._instanceLabel = None
         if (self.plugin_name is not None and argv is not None and len(argv) > 0 
             and re.search('_$', self.plugin_name)):
             mobj = re.match("%s(\S+)$" % self.plugin_name, 
@@ -122,8 +128,21 @@ class MuninPlugin:
             if mobj:
                 self.arg0 = mobj.group(1)
         self._parseEnv()
-        self.envRegisterFilter('graphs', '^[\w\-]+$')
-        self._nestedGraphs = self.envCheckFlag('nested_graphs', True)
+        if self.isMultigraph:
+            self.envRegisterFilter('graphs', '^[\w\-]+$')
+            self._nestedGraphs = self.envCheckFlag('nested_graphs', True)
+            if self.isMultiInstance:
+                self._instanceName = self.envGet('instance_name')
+                if self._instanceName is not None:
+                    label_type = self.envGet('instance_label_format', 
+                                             'suffix').lower()
+                    if label_type in ('suffix', 'prefix'):
+                        self._instanceLabel = self.envGet('instance_label',
+                                                          self._instanceName)
+                        self._instanceLabelType = label_type
+                    else:
+                        self._instanceLabel = None
+                        self._instanceLabelType = None
                 
     def _parseEnv(self, env=None):
         """Private method for parsing through environment variables.
@@ -154,6 +173,7 @@ class MuninPlugin:
         @param fail_noexist: If true throw exception if there is no graph with
                              name graph_name.
         @return:             Graph Object or None
+        
         """
         graph = self._graphDict.get(graph_name)
         if fail_noexist and graph is None:
@@ -190,6 +210,98 @@ class MuninPlugin:
             raise AttributeError("Invalid parent graph name %s "
                                  "for subgraph %s."
                                  % (parent_name, graph_name))
+    
+    def _getMultigraphID(self, graph_name, subgraph_name=None):
+        """Private method for generating Multigraph ID from graph name and 
+        subgraph name. 
+        
+        @param  graph_name:     Graph Name.
+        @param  subgraph_name:  Subgraph Name.
+        @return:                Multigraph ID.
+        
+        """
+        if self.isMultiInstance and self._instanceName is not None:
+            if subgraph_name is None:
+                return "%s_%s" % (graph_name, self._instanceName)
+            else:
+                return "%s_%s.%s_%s" % (graph_name, self._instanceName, 
+                                        subgraph_name, self._instanceName)
+        else:
+            if subgraph_name is None:
+                return graph_name
+            else:
+                return "%s.%s" % (graph_name, subgraph_name)
+            
+    def _formatConfig(self, conf_dict):
+        """Formats configuration directory from Munin Graph and returns 
+        multi-line value entries for the plugin config cycle.
+        
+        @param conf_dict: Configuration directory. 
+        @return:          Multi-line text.
+        
+        """
+        confs = []
+        graph_dict = conf_dict['graph']
+        field_list = conf_dict['fields']
+        
+        # Order and format Graph Attributes
+        title = graph_dict.get('title')
+        if title is not None:
+            if self.isMultiInstance and self._instanceLabel is not None:
+                if self._instanceLabelType == 'suffix':
+                    confs.append("graph_%s %s - %s" % ('title', 
+                                                       title, 
+                                                       self._instanceLabel,))
+                elif self._instanceLabelType == 'prefix':
+                    confs.append("graph_%s %s - %s" % ('title', 
+                                                       self._instanceLabel,
+                                                       title,))
+            else:
+                confs.append("graph_%s %s" % ('title', title))
+        for key in ('category', 'vlabel', 'info', 'args', 'period', 
+                    'scale', 'total', 'order', 'printf', 'width', 'height'):
+            val = graph_dict.get(key)
+            if val is not None:
+                if isinstance(val, bool):
+                    if val:
+                        val = "yes"
+                    else:
+                        val = "no"
+                confs.append("graph_%s %s" % (key, val))
+
+        # Order and Format Field Attributes
+        for (field_name, field_attrs) in field_list:
+            for key in ('label', 'type', 'draw', 'info', 'extinfo', 'colour',
+                        'negative', 'graph', 'min', 'max', 'cdef', 
+                        'line', 'warning', 'critical'):
+                val = field_attrs.get(key)
+                if val is not None:
+                    if isinstance(val, bool):
+                        if val:
+                            val = "yes"
+                        else:
+                            val = "no"
+                    confs.append("%s.%s %s" % (field_name, key, val))
+        return "\n".join(confs)
+    
+    def _formatVals(self, val_list):
+        """Formats value list from Munin Graph and returns multi-line value
+        entries for the plugin fetch cycle.
+        
+        @param val_list: List of name-value pairs. 
+        @return:         Multi-line text.
+        
+        """
+        vals = []
+        for (name, val) in val_list:
+            if val is not None:
+                if isinstance(val, float):
+                    vals.append("%s.value %f" % (name, val))
+                else:
+                    vals.append("%s.value %s" % (name, val))
+            else:
+                vals.append("%s.value U" % (name,))
+        return "\n".join(vals)
             
     def envHasKey(self, name):
         """Return True if environment variable with name exists.  
@@ -329,7 +441,7 @@ class MuninPlugin:
         @return:           Returns True if graph is enabled, False otherwise.
             
         """
-        return self.envCheckFilter('graphs', graph_name)
+        return not self.isMultigraph or self.envCheckFilter('graphs', graph_name)
         
     def saveState(self,  stateObj):
         """Utility methos to save plugin state stored in stateObj to persistent 
@@ -566,15 +678,16 @@ class MuninPlugin:
         for parent_name in self._graphNames:
             graph = self._graphDict[parent_name]
             if self.isMultigraph:
-                print "multigraph %s" % parent_name
-            print graph.getConfig()
+                print "multigraph %s" % self._getMultigraphID(parent_name)
+            print self._formatConfig(graph.getConfig())
             print
         if self._nestedGraphs and self._subgraphDict and self._subgraphNames:
             for (parent_name, subgraph_names) in self._subgraphNames.iteritems():
                 for graph_name in subgraph_names:
                     graph = self._subgraphDict[parent_name][graph_name]
-                    print "multigraph %s.%s" % (parent_name, graph_name)
-                    print graph.getConfig()
+                    print "multigraph %s" % self.getMultigraphID(parent_name, 
+                                                                 graph_name)
+                    print self._formatConfig(graph.getConfig())
                     print
         return True
 
@@ -597,15 +710,16 @@ class MuninPlugin:
         for parent_name in self._graphNames:
             graph = self._graphDict[parent_name]
             if self.isMultigraph:
-                print "multigraph %s" % parent_name
-            print graph.getVals()
+                print "multigraph %s" % self._getMultigraphID(parent_name)
+            print self._formatVals(graph.getVals())
             print
         if self._nestedGraphs and self._subgraphDict and self._subgraphNames:
             for (parent_name, subgraph_names) in self._subgraphNames.iteritems():
                 for graph_name in subgraph_names:
                     graph = self._subgraphDict[parent_name][graph_name]
-                    print "multigraph %s.%s" % (parent_name,  graph_name)
-                    print graph.getVals()
+                    print "multigraph %s" % self.getMultigraphID(parent_name, 
+                                                                 graph_name)
+                    print self._formatVals(graph.getVals())
                     print
         return True
 
@@ -732,40 +846,14 @@ class MuninGraph:
         return self._fieldNameList
     
     def getConfig(self):
-        """Returns config entries for Munin Graph.
+        """Returns dictionary of config entries for Munin Graph.
         
-        @return: Multi-line text output with Munin Graph configuration. 
+        @return: Dictionary of config entries. 
         
         """
-        conf = []
-        
-        # Process Graph Attributes
-        for key in ('title', 'category', 'vlabel', 'info', 'args', 'period', 
-                    'scale', 'total', 'order', 'printf', 'width', 'height'):
-            val = self._graphAttrDict.get(key)
-            if val is not None:
-                if isinstance(val, bool):
-                    if val:
-                        val = "yes"
-                    else:
-                        val = "no"
-                conf.append("graph_%s %s" % (key,val))
-
-        # Process Field Attributes
-        for field_name in self._fieldNameList:
-            field_attrs = self._fieldAttrDict.get(field_name)
-            for key in ('label', 'type', 'draw', 'info', 'extinfo', 'colour',
-                        'negative', 'graph', 'min', 'max', 'cdef', 
-                        'line', 'warning', 'critical'):
-                val = field_attrs.get(key)
-                if val is not None:
-                    if isinstance(val, bool):
-                        if val:
-                            val = "yes"
-                        else:
-                            val = "no"
-                    conf.append("%s.%s %s" % (field_name, key, val))
-        return "\n".join(conf)
+        return {'graph': self._graphAttrDict,
+                'fields': [(field_name, self._fieldAttrDict.get(field_name))
+                           for field_name in self._fieldNameList]}
 
     def setVal(self, name, val):
         """Set value for field in graph.
@@ -776,26 +864,16 @@ class MuninGraph:
         """
         if self._autoFixNames:
             name = self._fixName(name)
-        if val is not None:
-            self._fieldValDict[name] = val
-        else:
-            self._fieldValDict[name] = 'U'
+        self._fieldValDict[name] = val
 
     def getVals(self):
-        """Returns value entries for Munin Graph
+        """Returns value list for Munin Graph
         
-        @return: Multi-line text output with Munin Graph values.
+        @return: List of name-value pairs.
         
         """
-        vals = []
-        for name in self._fieldNameList:
-            val = self._fieldValDict.get(name)
-            if val is not None:
-                if isinstance(val, float):
-                    vals.append("%s.value %f" % (name, val))
-                else:
-                    vals.append("%s.value %s" % (name, val))
-        return "\n".join(vals)
+        return [(name, self._fieldValDict.get(name)) 
+                for name in self._fieldNameList]
     
     def _fixName(self, name):
         """Replace invalid characters in field names with underscore.
