@@ -24,7 +24,6 @@ Multigraph Plugin - Graph Structure
 
 
 Environment Variables
-
   amihost:        IP of Asterisk Server. (Default: 127.0.0.1)
   amiport:        Asterisk Manager Interface Port. (Default: 5038)
   amiuser:        Asterisk Manager Interface User.
@@ -47,6 +46,15 @@ Environment Variables
   exclude_graphs: Comma separated list of disabled graphs.
 
   Note: Channel, codec and trunk expressions are case insensitive.
+  
+Environment Variables for Multiple Instances of Plugin (Omitted by default.)
+  instance_name:         Name of instance.
+  instance_label:        Graph title label for instance.
+                         (Default is the same as instance name.)
+  instance_label_format: One of the following values:
+                         - suffix (Default)
+                         - prefix
+                         - none
 
   Example:
       [asteriskstats]
@@ -59,8 +67,8 @@ Environment Variables
 
 """
 # Munin  - Magic Markers
-#%# family=manual
-#%# capabilities=noautoconf nosuggest
+#%# family=auto
+#%# capabilities=autoconf nosuggest
 
 import sys
 import re
@@ -71,7 +79,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = []
 __license__ = "GPL"
-__version__ = "0.9.1"
+__version__ = "0.9.20"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -83,8 +91,9 @@ class MuninAsteriskPlugin(MuninPlugin):
     """
     plugin_name = 'asteriskstats'
     isMultigraph = True
+    isMultiInstance = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -96,11 +105,11 @@ class MuninAsteriskPlugin(MuninPlugin):
 
         self.envRegisterFilter('queues', '^[\w\-]+$')
         self._amihost = self.envGet('amihost')
-        self._amiport = self.envGet('amiport')
+        self._amiport = self.envGet('amiport', None, int)
         self._amiuser = self.envGet('amiuser')
         self._amipass = self.envGet('amipass')
+        self._category = 'Asterisk'
         
-                
         self._ami = AsteriskInfo(self._amihost, self._amiport, 
                                  self._amiuser, self._amipass)
         
@@ -126,7 +135,7 @@ class MuninAsteriskPlugin(MuninPlugin):
                 self._trunkList.append(mobj.groups())
                  
         if self.graphEnabled('asterisk_calls'):
-            graph = MuninGraph('Asterisk - Call Stats', 'Asterisk',
+            graph = MuninGraph('Asterisk - Call Stats', self._category,
                 info='Asterisk - Information on Calls.', period='minute',
                 args='--base 1000 --lower-limit 0')
             graph.addField('active_calls', 'active_calls', type='GAUGE',
@@ -136,7 +145,7 @@ class MuninAsteriskPlugin(MuninPlugin):
             self.appendGraph('asterisk_calls', graph)
 
         if self.graphEnabled('asterisk_channels'):
-            graph = MuninGraph('Asterisk - Active Channels', 'Asterisk',
+            graph = MuninGraph('Asterisk - Active Channels', self._category,
                 info='Asterisk - Information on Active Channels.',
                 args='--base 1000 --lower-limit 0')
             for field in self._chanList:
@@ -147,7 +156,7 @@ class MuninAsteriskPlugin(MuninPlugin):
 
         if (self.graphEnabled('asterisk_peers_sip') 
             and self._ami.hasChannelType('sip')):
-            graph = MuninGraph('Asterisk - VoIP Peers - SIP', 'Asterisk',
+            graph = MuninGraph('Asterisk - VoIP Peers - SIP', self._category,
                 info='Asterisk - Information on SIP VoIP Peers.',
                 args='--base 1000 --lower-limit 0')
             for field in ('online', 'unmonitored', 'unreachable', 
@@ -157,7 +166,7 @@ class MuninAsteriskPlugin(MuninPlugin):
 
         if (self.graphEnabled('asterisk_peers_iax2') 
             and self._ami.hasChannelType('iax2')):
-            graph = MuninGraph('Asterisk - VoIP Peers - IAX2', 'Asterisk',
+            graph = MuninGraph('Asterisk - VoIP Peers - IAX2', self._category,
                 info='Asterisk - Information on IAX2 VoIP Peers.',
                 args='--base 1000 --lower-limit 0')
             for field in ('online', 'unmonitored', 'unreachable', 
@@ -169,7 +178,7 @@ class MuninAsteriskPlugin(MuninPlugin):
             and (self._ami.hasChannelType('sip') 
                  or self._ami.hasChannelType('iax2'))):
             graph = MuninGraph('Asterisk - VoIP Codecs for Active Channels', 
-                'Asterisk',
+                self._category,
                 info='Asterisk - Codecs for Active VoIP Channels (SIP/IAX2)',
                 args='--base 1000 --lower-limit 0')
             for field in self._codecList:
@@ -179,7 +188,7 @@ class MuninAsteriskPlugin(MuninPlugin):
 
         if (self.graphEnabled('asterisk_conferences') 
             and self._ami.hasConference()):
-            graph = MuninGraph('Asterisk - Conferences', 'Asterisk',
+            graph = MuninGraph('Asterisk - Conferences', self._category,
                 info='Asterisk - Information on Meetme Conferences',
                 args='--base 1000 --lower-limit 0')
             graph.addField('rooms', 'rooms', type='GAUGE', draw='LINE2', 
@@ -190,7 +199,7 @@ class MuninAsteriskPlugin(MuninPlugin):
 
         if (self.graphEnabled('asterisk_voicemail')
             and self._ami.hasVoicemail()):
-            graph = MuninGraph('Asterisk - Voicemail', 'Asterisk',
+            graph = MuninGraph('Asterisk - Voicemail', self._category,
                 info='Asterisk - Information on Voicemail Accounts',
                 args='--base 1000 --lower-limit 0')
             graph.addField('accounts', 'accounts', type='GAUGE', draw='LINE2',
@@ -204,7 +213,7 @@ class MuninAsteriskPlugin(MuninPlugin):
             self.appendGraph('asterisk_voicemail', graph)
 
         if self.graphEnabled('asterisk_trunks') and len(self._trunkList) > 0:
-            graph = MuninGraph('Asterisk - Trunks', 'Asterisk',
+            graph = MuninGraph('Asterisk - Trunks', self._category,
                 info='Asterisk - Active calls on trunks.',
                 args='--base 1000 --lower-limit 0',
                 autoFixNames = True)
@@ -232,7 +241,7 @@ class MuninAsteriskPlugin(MuninPlugin):
         
         if self._queues is not None and len(self._queue_list) > 0:
             if self.graphEnabled('asterisk_queue_len'):
-                graph = MuninGraph('Asterisk - Queues - Calls in Queue', 'Asterisk',
+                graph = MuninGraph('Asterisk - Queues - Calls in Queue', self._category,
                     info='Asterisk - Queues - Number of calls in queues.',
                     args='--base 1000 --lower-limit 0')
                 for queue in self._queue_list:
@@ -241,7 +250,7 @@ class MuninAsteriskPlugin(MuninPlugin):
                 self.appendGraph('asterisk_queue_len', graph)
             if self.graphEnabled('asterisk_queue_avg_hold'):
                 graph = MuninGraph('Asterisk - Queues - Average Hold Time (sec)', 
-                    'Asterisk',
+                    self._category,
                     info='Asterisk - Queues - Average Hold Time.',
                     args='--base 1000 --lower-limit 0')
                 for queue in self._queue_list:
@@ -250,7 +259,7 @@ class MuninAsteriskPlugin(MuninPlugin):
                 self.appendGraph('asterisk_queue_avg_hold', graph)
             if self.graphEnabled('asterisk_queue_avg_talk'):
                 graph = MuninGraph('Asterisk - Queues - Average Talk Time (sec)', 
-                    'Asterisk',
+                    self._category,
                     info='Asterisk - Queues - Average Talk Time.).',
                     args='--base 1000 --lower-limit 0')
                 for queue in self._queue_list:
@@ -259,7 +268,7 @@ class MuninAsteriskPlugin(MuninPlugin):
                 self.appendGraph('asterisk_queue_avg_talk', graph)
             if self.graphEnabled('asterisk_queue_calls'):
                 graph = MuninGraph('Asterisk - Queues - Calls per Minute', 
-                    'Asterisk', period='minute',
+                    self._category, period='minute',
                     info='Asterisk - Queues - Abandoned/Completed Calls per minute.',
                     args='--base 1000 --lower-limit 0')
                 graph.addField('abandon', 'abandon', type='DERIVE', draw='AREASTACK',
@@ -269,7 +278,7 @@ class MuninAsteriskPlugin(MuninPlugin):
                 self.appendGraph('asterisk_queue_calls', graph)
             if self.graphEnabled('asterisk_queue_abandon_pcent'):
                 graph = MuninGraph('Asterisk - Queues - Abandoned Calls (%)', 
-                    'Asterisk',
+                    self._category,
                     info='Asterisk - Queues - Abandoned calls vs, total calls.',
                     args='--base 1000 --lower-limit 0')
                 for queue in self._queue_list:
@@ -281,7 +290,7 @@ class MuninAsteriskPlugin(MuninPlugin):
         if self._ami.hasFax():
             if self.graphEnabled('asterisk_fax_attempts'):
                 graph = MuninGraph('Asterisk - Fax Stats', 
-                    'Asterisk', period='minute',
+                    self._category, period='minute',
                     info='Asterisk - Fax - Fax Recv / Send Attempts per minute.',
                     args='--base 1000 --lower-limit 0')
                 graph.addField('send', 'send', type='DERIVE', draw='AREASTACK',
@@ -411,6 +420,14 @@ class MuninAsteriskPlugin(MuninPlugin):
                     self.setGraphVal('asterisk_fax_attempts', 'fail', 
                                      stats.get('failed faxes'))
 
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        return self._ami.checkVersion('1.2')
+        
 
 def main():
     sys.exit(muninMain(MuninAsteriskPlugin))
