@@ -39,7 +39,7 @@ Environment Variables
 """
 # Munin  - Magic Markers
 #%# family=auto
-#%# capabilities=noautoconf nosuggest
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import (MuninGraph, MuninPlugin, muninMain, 
@@ -64,7 +64,7 @@ class MuninDiskIOplugin(MuninPlugin):
     plugin_name = 'diskiostats'
     isMultigraph = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -73,6 +73,7 @@ class MuninDiskIOplugin(MuninPlugin):
         
         """
         MuninPlugin.__init__(self, argv, env, debug)
+        self._category = 'Disk IO'
 
         self._info = DiskIOinfo()
         
@@ -146,7 +147,7 @@ class MuninDiskIOplugin(MuninPlugin):
         """
         name = 'diskio_%s_requests' % namestr
         if self.graphEnabled(name):
-            graph = MuninGraph('Disk I/O - %s - Requests' % titlestr, 'Disk I/O',
+            graph = MuninGraph('Disk I/O - %s - Requests' % titlestr, self._category,
                 info='Disk I/O - %s Throughput, Read / write requests per second.' 
                      % titlestr,
                 args='--base 1000 --lower-limit 0',
@@ -176,7 +177,7 @@ class MuninDiskIOplugin(MuninPlugin):
         """
         name = 'diskio_%s_bytes' % namestr
         if self.graphEnabled(name):
-            graph = MuninGraph('Disk I/O - %s - Throughput' % titlestr, 'Disk I/O',
+            graph = MuninGraph('Disk I/O - %s - Throughput' % titlestr, self._category,
                 info='Disk I/O - %s Throughput, bytes read / written per second.'
                      % titlestr,
                 args='--base 1000 --lower-limit 0', printf='%6.1lf',
@@ -207,7 +208,7 @@ class MuninDiskIOplugin(MuninPlugin):
         name = 'diskio_%s_active' % namestr
         if self.graphEnabled(name):
             graph = MuninGraph('Disk I/O - %s - Queue Length' % titlestr, 
-                'Disk I/O',
+                self._category,
                 info='Disk I/O - Number  of I/O Operations in Progress for every %s.'
                      % titlestr,
                 args='--base 1000 --lower-limit 0', printf='%6.1lf',
@@ -241,6 +242,15 @@ class MuninDiskIOplugin(MuninPlugin):
             name = 'diskio_%s_active' % namestr
             if self.hasGraph(name):
                 self.setGraphVal(name, dev, stats['ios_active'])
+                
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        # If no exception is thrown during initialization, the plugin should work.
+        return True
         
 
 def main():
