@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """diskusagestats - Munin Plugin to monitor disk space and inode usage of 
 filesystems.
 
@@ -37,7 +37,7 @@ Environment Variables
 """
 # Munin  - Magic Markers
 #%# family=auto
-#%# capabilities=noautoconf nosuggest
+#%# capabilities=autoconf nosuggest
 
 import sys
 from pymunin import (MuninGraph, MuninPlugin, muninMain, 
@@ -61,7 +61,7 @@ class MuninDiskUsagePlugin(MuninPlugin):
     plugin_name = 'diskusagestats'
     isMultigraph = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -73,6 +73,7 @@ class MuninDiskUsagePlugin(MuninPlugin):
         
         self.envRegisterFilter('fspaths', '^[\w\-\/]+$')
         self.envRegisterFilter('fstypes', '^\w+$')
+        self._category = 'Disk Usage'
         
         self._statsSpace = None
         self._statsInode = None
@@ -86,7 +87,7 @@ class MuninDiskUsagePlugin(MuninPlugin):
         name = 'diskspace'
         if self.graphEnabled(name):
             self._statsSpace = self._info.getSpaceUse()
-            graph = MuninGraph('Disk Space Usage (%)', 'Disk Usage',
+            graph = MuninGraph('Disk Space Usage (%)', self._category,
                 info='Disk space usage of filesystems.',
                 args='--base 1000 --lower-limit 0', printf='%6.1lf',
                 autoFixNames=True)
@@ -102,7 +103,7 @@ class MuninDiskUsagePlugin(MuninPlugin):
         name = 'diskinode'
         if self.graphEnabled(name):
             self._statsInode = self._info.getInodeUse()
-            graph = MuninGraph('Inode Usage (%)', 'Disk Usage',
+            graph = MuninGraph('Inode Usage (%)', self._category,
                 info='Inode usage of filesystems.',
                 args='--base 1000 --lower-limit 0', printf='%6.1lf',
                 autoFixNames=True)
@@ -147,6 +148,15 @@ class MuninDiskUsagePlugin(MuninPlugin):
             
         """
         return self.envCheckFilter('fstypes', fstype)
+    
+    def autoconf(self):
+        """Implements Munin Plugin Auto-Configuration Option.
+        
+        @return: True if plugin can be  auto-configured, False otherwise.
+                 
+        """
+        # If no exception is thrown during initialization, the plugin should work.
+        return True
 
 
 def main():
