@@ -46,6 +46,15 @@ Environment Variables
                   (All graphs enabled by default.)
   exclude_graphs: Comma separated list of disabled graphs.
 
+Environment Variables for Multiple Instances of Plugin (Omitted by default.)
+  instance_name:         Name of instance.
+  instance_label:        Graph title label for instance.
+                         (Default is the same as instance name.)
+  instance_label_format: One of the following values:
+                         - suffix (Default)
+                         - prefix
+                         - none 
+
   Example:
     [mysqlstats]
         user root
@@ -65,7 +74,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = ["Kjell-Magne Oierud (kjellm at GitHub)"]
 __license__ = "GPL"
-__version__ = "0.9.14"
+__version__ = "0.9.20"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -77,8 +86,9 @@ class MuninMySQLplugin(MuninPlugin):
     """
     plugin_name = 'pgstats'
     isMultigraph = True
+    isMultiInstance = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -95,17 +105,18 @@ class MuninMySQLplugin(MuninPlugin):
         self._database = self.envGet('database')
         self._user = self.envGet('user')
         self._password = self.envGet('password')
+        self._category = 'MySQL'
+        
         self._engines = None
         self._genStats = None
         self._genVars = None
         self._dbList = None
-        
         self._dbconn = MySQLinfo(self._host, self._port, self._database, 
                               self._user, self._password)
         
         if self.graphEnabled('mysql_connections'):
             graph = MuninGraph('MySQL - Connections per second', 
-                'MySQL',
+                self._category,
                 info='MySQL Server new and aborted connections per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('conn', 'conn', draw='LINE2', 
@@ -122,7 +133,7 @@ class MuninMySQLplugin(MuninPlugin):
         
         if self.graphEnabled('mysql_traffic'):
             graph = MuninGraph('MySQL - Network Traffic (bytes/sec)', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Network Traffic in bytes per second.',
                 args='--base 1000 --lower-limit 0',
                 vlabel='bytes in (-) / out (+) per second')
@@ -135,7 +146,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_slowqueries'):
             graph = MuninGraph('MySQL - Slow Queries per second', 
-                'MySQL',
+                self._category,
                 info='The number of queries that have taken more than '
                      'long_query_time seconds.',
                 args='--base 1000 --lower-limit 0')
@@ -145,7 +156,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_rowmodifications'):
             graph = MuninGraph('MySQL - Row Insert, Delete, Updates per second', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Inserted, Deleted, Updated Rows per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('insert', 'insert', draw='AREASTACK', 
@@ -161,7 +172,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_rowreads'):
             graph = MuninGraph('MySQL - Row Reads per second', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Row Reads per second.',
                 args='--base 1000 --lower-limit 0')
             for (field, desc) in (('first', 
@@ -182,7 +193,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_tablelocks'):
             graph = MuninGraph('MySQL - Table Locks per second', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Table Locks per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('waited', 'waited', draw='AREASTACK', 
@@ -197,7 +208,7 @@ class MuninMySQLplugin(MuninPlugin):
         
         if self.graphEnabled('mysql_threads'):
             graph = MuninGraph('MySQL - Threads', 
-                'MySQL',
+                self._category,
                 info='Number of active and idle threads for MySQL Server.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('running', 'running', draw='AREASTACK', type='GAUGE', 
@@ -213,7 +224,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_proc_status'):
             graph = MuninGraph('MySQL - Process Status', 
-                'MySQL',
+                self._category,
                 info='Number of threads discriminated by process status.',
                 args='--base 1000 --lower-limit 0')
             for (field, label, desc) in (
@@ -271,7 +282,7 @@ class MuninMySQLplugin(MuninPlugin):
                 self._dbList = self._dbconn.getDatabases()
                 self._dbList.sort()
             graph = MuninGraph('MySQL - Processes per Database', 
-                'MySQL',
+                self._category,
                 info='Number of Threads discriminated by database.',
                 args='--base 1000 --lower-limit 0', autoFixNames=True)
             for db in self._dbList:
@@ -281,7 +292,7 @@ class MuninMySQLplugin(MuninPlugin):
                 
         if self.graphEnabled('mysql_commits_rollbacks'):
             graph = MuninGraph('MySQL - Commits and Rollbacks', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Commits and Rollbacks per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('commit', 'commit', draw='LINE2', 
@@ -294,7 +305,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_qcache_memory'):
             graph = MuninGraph('MySQL - Query Cache - Memory Use (bytes)', 
-                'MySQL',
+                self._category,
                 info='Memory utilization for MySQL Server Query Cache.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('used', 'used', draw='AREASTACK', type='GAUGE', 
@@ -305,7 +316,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_qcache_hits'):
             graph = MuninGraph('MySQL - Query Cache - Hits', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Query Cache Hits vs. Select Queries.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('hits', 'hits', draw='AREASTACK', 
@@ -318,7 +329,7 @@ class MuninMySQLplugin(MuninPlugin):
             
         if self.graphEnabled('mysql_qcache_prunes'):
             graph = MuninGraph('MySQL - Query Cache - Inserts/Prunes per second', 
-                'MySQL',
+                self._category,
                 info='MySQL Server Query Cache Inserts and Low Memory Prune'
                      ' operations per second.',
                 args='--base 1000 --lower-limit 0')
@@ -335,7 +346,7 @@ class MuninMySQLplugin(MuninPlugin):
             
             if self.graphEnabled('mysql_myisam_key_buffer_util'):
                 graph = MuninGraph('MyISAM - Key Buffer Utilization (bytes)', 
-                    'MySQL',
+                    self._category,
                     info='MySQL Server MyISAM Key Buffer Utilization'
                          ' in bytes.',
                     args='--base 1000 --lower-limit 0')
@@ -352,7 +363,7 @@ class MuninMySQLplugin(MuninPlugin):
             
             if self.graphEnabled('mysql_myisam_key_read_reqs'):
                 graph = MuninGraph('MyISAM - Key Block Read Requests per second', 
-                    'MySQL',
+                    self._category,
                     info='MySQL Server MyISAM Key block read requests satisfied '
                          ' from block cache (hits) vs. disk (misses).',
                     args='--base 1000 --lower-limit 0')
@@ -371,7 +382,7 @@ class MuninMySQLplugin(MuninPlugin):
             
             if self.graphEnabled('mysql_innodb_buffer_pool_util'):
                 graph = MuninGraph('InnoDB - Buffer Pool Utilization (bytes)', 
-                    'MySQL',
+                    self._category,
                     info='MySQL Server InnoDB Buffer Pool Utilization in bytes.',
                     args='--base 1000 --lower-limit 0')
                 graph.addField('dirty', 'dirty', draw='AREASTACK', type='GAUGE', 
@@ -389,7 +400,7 @@ class MuninMySQLplugin(MuninPlugin):
                 
             if self.graphEnabled('mysql_innodb_buffer_pool_activity'):
                 graph = MuninGraph('InnoDB - Buffer Pool Activity (Pages per second)', 
-                    'MySQL',
+                    self._category,
                     info='MySQL Server Pages read into, written from and created'
                          ' in InnoDB buffer pool.',
                     args='--base 1000 --lower-limit 0')
@@ -406,7 +417,7 @@ class MuninMySQLplugin(MuninPlugin):
                 
             if self.graphEnabled('mysql_innodb_buffer_pool_read_reqs'):
                 graph = MuninGraph('InnoDB - Buffer Pool Read Requests per second', 
-                    'MySQL',
+                    self._category,
                     info='MySQL Server read requests satisfied from InnoDB buffer'
                          ' pool (hits) vs. disk (misses).',
                     args='--base 1000 --lower-limit 0')
@@ -423,7 +434,7 @@ class MuninMySQLplugin(MuninPlugin):
                     
             if self.graphEnabled('mysql_innodb_row_ops'):
                 graph = MuninGraph('InnoDB - Row Operations per Second', 
-                    'MySQL',
+                    self._category,
                     info='MySQL Server InnoDB Inserted, updated, deleted, read'
                          ' rows per second.',
                     args='--base 1000 --lower-limit 0')
