@@ -22,6 +22,15 @@ Environment Variables
                   (All graphs enabled by default.)
   exclude_graphs: Comma separated list of disabled graphs.
 
+Environment Variables for Multiple Instances of Plugin (Omitted by default.)
+  instance_name:         Name of instance.
+  instance_label:        Graph title label for instance.
+                         (Default is the same as instance name.)
+  instance_label_format: One of the following values:
+                         - suffix (Default)
+                         - prefix
+                         - none 
+
   Example:
     [ntphostoffsets]
         env.ntphosts 192.168.1.1,192.168.1.2
@@ -41,7 +50,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = []
 __license__ = "GPL"
-__version__ = "0.9"
+__version__ = "0.9.20"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -54,8 +63,9 @@ class MuninNTPhostOffsetsPlugin(MuninPlugin):
     """
     plugin_name = 'ntphostoffsets'
     isMultigraph = True
+    isMultiInstance = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -64,6 +74,7 @@ class MuninNTPhostOffsetsPlugin(MuninPlugin):
         
         """
         MuninPlugin.__init__(self, argv, env, debug)
+        self._category = 'Time'
 
         if self.envHasKey('ntphosts'):
             hosts_str = re.sub('[^\d\.,]', '', self.envGet('ntphosts'))
@@ -73,7 +84,7 @@ class MuninNTPhostOffsetsPlugin(MuninPlugin):
                                  "'ntphosts' environment variable.")
 
         if self.graphEnabled('ntp_host_stratums'):
-            graph = MuninGraph('NTP Stratums of Multiple Hosts', 'Time',
+            graph = MuninGraph('NTP Stratums of Multiple Hosts', self._category,
                 info='NTP Stratum of Multiple Remote Hosts.',
                 args='--base 1000 --lower-limit 0')
             for host in self._remoteHosts:
@@ -82,7 +93,7 @@ class MuninNTPhostOffsetsPlugin(MuninPlugin):
             self.appendGraph('ntp_host_stratums', graph)
 
         if self.graphEnabled('ntp_host_offsets'):
-            graph = MuninGraph('NTP Offsets of Multiple Hosts', 'Time',
+            graph = MuninGraph('NTP Offsets of Multiple Hosts', self._category,
                 info='NTP Delays of Multiple Hosts relative to current node.',
                 args ='--base 1000 --lower-limit 0',
                 vlabel='seconds'
@@ -93,7 +104,7 @@ class MuninNTPhostOffsetsPlugin(MuninPlugin):
             self.appendGraph('ntp_host_offsets', graph)
     
         if self.graphEnabled('ntp_host_delays'):
-            graph = MuninGraph('NTP Delays of Multiple Hosts', 'Time',
+            graph = MuninGraph('NTP Delays of Multiple Hosts', self._category,
                 info='NTP Delays of Multiple Hosts relative to current node.',
                 args='--base 1000 --lower-limit 0',
                 vlabel='seconds'
