@@ -46,15 +46,24 @@ Environment Variables
                   Must be specified for network connections.)
   password:       Database User Password
                   (Attempt login without password by default.)
-  include_db:     Comma separated list of databases to include in detail graphs.
+  include_db:     Comma separated list of databases to include in graphs.
                   (All enabled by default.)
-  exclude_db:     Comma separated list of databases to exclude from detail graphs.
+  exclude_db:     Comma separated list of databases to exclude from graphs.
   detail_graphs:  Enable (on) / disable (off) detail graphs. 
                   (Disabled by default.)
   repl_graphs:    Enable (on) / disable (off) replication status graphs.
   include_graphs: Comma separated list of enabled graphs. 
                   (All graphs enabled by default.)
   exclude_graphs: Comma separated list of disabled graphs.
+  
+Environment Variables for Multiple Instances of Plugin (Omitted by default.)
+  instance_name:         Name of instance.
+  instance_label:        Graph title label for instance.
+                         (Default is the same as instance name.)
+  instance_label_format: One of the following values:
+                         - suffix (Default)
+                         - prefix
+                         - none 
 
   Example:
     [pgstats]
@@ -75,7 +84,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = []
 __license__ = "GPL"
-__version__ = "0.9.19"
+__version__ = "0.9.20"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -87,8 +96,9 @@ class MuninPgPlugin(MuninPlugin):
     """
     plugin_name = 'pgstats'
     isMultigraph = True
+    isMultiInstance = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -106,6 +116,8 @@ class MuninPgPlugin(MuninPlugin):
         self._password = self.envGet('password')
         self._detailGraphs = self.envCheckFlag('detail_graphs', False)
         self._replGraphs = self.envCheckFlag('repl_graphs', False)
+        self._category_sys = 'PostgreSQL Sys'
+        self._category_db = 'PostgreSQL DB'
         
         self._dbconn = PgInfo(self._host, self._port, self._database, 
                               self._user, self._password)
@@ -115,7 +127,7 @@ class MuninPgPlugin(MuninPlugin):
         
         if self.graphEnabled('pg_connections'):
             graph = MuninGraph('PostgreSQL - Active Connections', 
-                'PostgreSQL Sys',
+                self._category_sys,
                 info='Active connections for PostgreSQL Database Server.',
                 args='--base 1000 --lower-limit 0',
                 autoFixNames = True)
@@ -132,7 +144,7 @@ class MuninPgPlugin(MuninPlugin):
         
         if self.graphEnabled('pg_diskspace'):
             graph = MuninGraph('PostgreSQL - Database Disk Usage', 
-                'PostgreSQL Sys',
+                self._category_sys,
                 info='Disk usage of databases on PostgreSQL Server in bytes.',
                 args='--base 1024 --lower-limit 0',
                 autoFixNames = True)
@@ -144,7 +156,7 @@ class MuninPgPlugin(MuninPlugin):
             self.appendGraph('pg_diskspace', graph)
         
         if self.graphEnabled('pg_blockreads'):
-            graph = MuninGraph('PostgreSQL - Block Read Stats', 'PostgreSQL Sys',
+            graph = MuninGraph('PostgreSQL - Block Read Stats', self._category_sys,
                 info='Block read stats for PostgreSQL Server.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('blk_hit', 'cache hits', draw='AREASTACK', 
@@ -157,7 +169,7 @@ class MuninPgPlugin(MuninPlugin):
             self.appendGraph('pg_blockreads', graph)
         
         if self.graphEnabled('pg_xact'):
-            graph = MuninGraph('PostgreSQL - Transactions', 'PostgreSQL Sys',
+            graph = MuninGraph('PostgreSQL - Transactions', self._category_sys,
                 info='Transaction commit / rollback Stats for PostgreSQL Server.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('commits', 'commits', draw='LINE2', type='DERIVE', 
@@ -169,7 +181,7 @@ class MuninPgPlugin(MuninPlugin):
         if self._dbconn.checkVersion('8.3'):
             if self.graphEnabled('pg_checkpoints'):
                 graph = MuninGraph('PostgreSQL - Checkpoints per minute', 
-                    'PostgreSQL Sys',
+                    self._category_sys,
                     info='Number of Checkpoints per Minute for PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0', period='minute')
                 graph.addField('req', 'req', draw='LINE2', type='DERIVE', 
@@ -179,7 +191,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_checkpoints', graph)
             if self.graphEnabled('pg_bgwriter'):
                 graph = MuninGraph('PostgreSQL - BgWriter Stats (blocks / second)', 
-                    'PostgreSQL Sys',
+                    self._category_sys,
                     info='PostgreSQL Server - Bgwriter - Blocks written per second.',
                     args='--base 1000 --lower-limit 0', period='minute')
                 graph.addField('backend', 'backend', draw='LINE2', 
@@ -193,7 +205,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_bgwriter', graph)
         
         if self.graphEnabled('pg_tup_read'):
-            graph = MuninGraph('PostgreSQL - Tuple Reads', 'PostgreSQL Sys',
+            graph = MuninGraph('PostgreSQL - Tuple Reads', self._category_sys,
                 info='Tuple return and fetch Stats for PostgreSQL Server.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('fetch', 'fetch', draw='AREASTACK', 
@@ -206,7 +218,7 @@ class MuninPgPlugin(MuninPlugin):
             self.appendGraph('pg_tup_read', graph)
             
         if self.graphEnabled('pg_tup_write'):
-            graph = MuninGraph('PostgreSQL - Tuple Writes', 'PostgreSQL Sys',
+            graph = MuninGraph('PostgreSQL - Tuple Writes', self._category_sys,
                 info='Tuple insert, update and delete Stats for PostgreSQL Server.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('delete', 'delete', draw='AREASTACK', type='DERIVE', 
@@ -225,7 +237,7 @@ class MuninPgPlugin(MuninPlugin):
             if self.graphEnabled(graph_name):
                 mode_iter = iter(PgInfo.lockModes)
                 graph = MuninGraph("PostgreSQL - Locks (%s)" % lock_state, 
-                    'PostgreSQL Sys',
+                    self._category_sys,
                     info=desc,
                     args='--base 1000 --lower-limit 0')
                 for mode in ('AccessExcl', 'Excl', 'ShrRwExcl', 'Shr', 
@@ -238,7 +250,7 @@ class MuninPgPlugin(MuninPlugin):
         if self._detailGraphs:        
             if self.graphEnabled('pg_blockread_detail'):
                 graph = MuninGraph('PostgreSQL - Block Read Stats Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Block read stats for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -249,7 +261,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_blockread_detail', graph)
             if self.graphEnabled('pg_xact_commit_detail'):
                 graph = MuninGraph('PostgreSQL - Transaction Commits Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Transaction commits for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -260,7 +272,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_xact_commit_detail', graph)
             if self.graphEnabled('pg_xact_rollback_detail'):
                 graph = MuninGraph('PostgreSQL - Transaction Rollbacks Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Transaction rollbacks for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -271,7 +283,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_xact_rollback_detail', graph)
             if self.graphEnabled('pg_tup_return_detail'):
                 graph = MuninGraph('PostgreSQL - Tuple Scan Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Tuple scans for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -282,7 +294,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_tup_return_detail', graph)
             if self.graphEnabled('pg_tup_fetch_detail'):
                 graph = MuninGraph('PostgreSQL - Tuple Fetch Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Tuple fetches for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -293,7 +305,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_tup_fetch_detail', graph)
             if self.graphEnabled('pg_tup_delete_detail'):
                 graph = MuninGraph('PostgreSQL - Tuple Delete Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Tuple deletes for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -304,7 +316,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_tup_delete_detail', graph)
             if self.graphEnabled('pg_tup_update_detail'):
                 graph = MuninGraph('PostgreSQL - Tuple Updates Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Tuple updates for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -315,7 +327,7 @@ class MuninPgPlugin(MuninPlugin):
                 self.appendGraph('pg_tup_update_detail', graph)
             if self.graphEnabled('pg_tup_insert_detail'):
                 graph = MuninGraph('PostgreSQL - Tuple Inserts Detail', 
-                    'PostgreSQL DB',
+                    self._category_db,
                     info='Tuple insertes for each database in PostgreSQL Server.',
                     args='--base 1000 --lower-limit 0',
                     autoFixNames = True)
@@ -331,7 +343,7 @@ class MuninPgPlugin(MuninPlugin):
                 graph_name = "pg_lock_%s_detail" % lock_state
                 if self.graphEnabled(graph_name):
                     graph = MuninGraph("PostgreSQL - Locks (%s) Detail" % lock_state, 
-                        'PostgreSQL Sys',
+                        self._category_sys,
                         info=desc,
                         args='--base 1000 --lower-limit 0',
                         autoFixNames = True)
