@@ -32,6 +32,15 @@ Environment Variables
                   (All graphs enabled by default.)
   exclude_graphs: Comma separated list of disabled graphs.
 
+Environment Variables for Multiple Instances of Plugin (Omitted by default.)
+  instance_name:         Name of instance.
+  instance_label:        Graph title label for instance.
+                         (Default is the same as instance name.)
+  instance_label_format: One of the following values:
+                         - suffix (Default)
+                         - prefix
+                         - none 
+
   Example:
     [phpapcstats]
         env.exclude_graphs php_apc_items,php_apc_expunge
@@ -49,7 +58,7 @@ __author__ = "Ali Onur Uyar"
 __copyright__ = "Copyright 2011, Ali Onur Uyar"
 __credits__ = []
 __license__ = "GPL"
-__version__ = "0.8"
+__version__ = "0.9.20"
 __maintainer__ = "Ali Onur Uyar"
 __email__ = "aouyar at gmail.com"
 __status__ = "Development"
@@ -61,8 +70,9 @@ class MuninPHPapcPlugin(MuninPlugin):
     """
     plugin_name = 'phpapcstats'
     isMultigraph = True
+    isMultiInstance = True
 
-    def __init__(self, argv=(), env={}, debug=False):
+    def __init__(self, argv=(), env=None, debug=False):
         """Populate Munin Plugin with MuninGraph instances.
         
         @param argv:  List of command line arguments.
@@ -78,9 +88,10 @@ class MuninPHPapcPlugin(MuninPlugin):
         self._monpath = self.envGet('monpath')
         self._password = self.envGet('password')
         self._ssl = self.envCheckFlag('ssl', False)
+        self._category = 'PHP'
         
         if self.graphEnabled('php_apc_memory'):
-            graph = MuninGraph('PHP APC Cache - Memory Utilization (bytes)', 'PHP',
+            graph = MuninGraph('PHP APC Cache - Memory Utilization (bytes)', self._category,
                 info='Memory Utilization of PHP APC Cache in bytes.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('filecache', 'File Cache', draw='AREASTACK', 
@@ -93,7 +104,7 @@ class MuninPHPapcPlugin(MuninPlugin):
             self.appendGraph('php_apc_memory', graph)
         
         if self.graphEnabled('php_apc_items'):
-            graph = MuninGraph('PHP APC Cache - Cached Items', 'PHP',
+            graph = MuninGraph('PHP APC Cache - Cached Items', self._category,
                 info='Number of items (files, user data) in PHP APC Cache.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('filecache', 'File Cache', draw='AREASTACK', 
@@ -103,7 +114,7 @@ class MuninPHPapcPlugin(MuninPlugin):
             self.appendGraph('php_apc_items', graph)
         
         if self.graphEnabled('php_apc_reqs_filecache'):
-            graph = MuninGraph('PHP APC - File Cache Requests per second', 'PHP',
+            graph = MuninGraph('PHP APC - File Cache Requests per second', self._category,
                 info='PHP APC File Cache Requests (Hits and Misses) per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('hits', 'hits', draw='AREASTACK', 
@@ -115,7 +126,7 @@ class MuninPHPapcPlugin(MuninPlugin):
             self.appendGraph('php_apc_reqs_filecache', graph)
         
         if self.graphEnabled('php_apc_reqs_usercache'):
-            graph = MuninGraph('PHP APC - User Cache Requests per second', 'PHP',
+            graph = MuninGraph('PHP APC - User Cache Requests per second', self._category,
                 info='PHP APC User Cache Requests (Hits and Misses) per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('hits', 'hits', draw='AREASTACK', 
@@ -127,7 +138,7 @@ class MuninPHPapcPlugin(MuninPlugin):
             self.appendGraph('php_apc_reqs_usercache', graph)
             
         if self.graphEnabled('php_apc_expunge'):
-            graph = MuninGraph('PHP APC - Cache Expunge Runs per second', 'PHP',
+            graph = MuninGraph('PHP APC - Cache Expunge Runs per second', self._category,
                 info='PHP APC File and User Cache Expunge Runs per second.',
                 args='--base 1000 --lower-limit 0')
             graph.addField('filecache', 'File Cache', draw='LINE2', 
